from setuptools import setup

setup(name="asciigif",
      version='0.1',
      description="Text-based GIF generation / output",
      url="https://github.com/CakeGamingHub/AsciiGIF",
      author="Motherflippin",
      author_email="cakephone5@gmail.com",
      license="MIT",
      packages=["asciigif"],
      zip_safe=False)